@@ -15,7 +15,7 @@ from collections import OrderedDict, defaultdict
 from dataclasses import dataclass
 from itertools import groupby
 from pathlib import Path
-from typing import Any, Dict, Generator, List, NamedTuple, Union, Tuple
+from typing import Any, Dict, Generator, List, NamedTuple, Tuple, Union
 from zipfile import BadZipFile
 
 from engine.config import Config
@@ -24,12 +24,13 @@ from engine.domain.template import TemplateCell
 from engine.exceptions import (
     DatamapFileEncodingError,
     DatamapNotCSVException,
+    MalFormedCSVEmptyTailRowsException,
     MalFormedCSVHeaderException,
     MissingCellKeyError,
     MissingLineError,
     MissingSheetFieldError,
-    NoApplicableSheetsInTemplateFiles,
     NestedZipError,
+    NoApplicableSheetsInTemplateFiles,
 )
 from engine.utils import ECHO_FUNC_GREEN, ECHO_FUNC_YELLOW
 from openpyxl import load_workbook
@@ -78,12 +79,41 @@ def _dml_line_check(line: OrderedDict, headers: Dict[str, str]) -> None:
         )
 
 
+def tail_rows_check(dm_file: Union[Path, str]):
+    first_fields = []
+    with DatamapFile(dm_file) as datamap_file:
+        print(f"Using {datamap_file}")
+        reader = csv.reader(datamap_file)
+        for line in reader:
+            try:
+                first_fields.append(line[0])
+            except IndexError:
+                break
+    empty_lines = 0
+    for item in first_fields[-5:]:
+        if item == "":
+            empty_lines += 1
+    # Let's say we can tolerate no more than 5 empty lines before baling
+    if empty_lines >= 5:
+        raise MalFormedCSVEmptyTailRowsException(
+            f"Too many empty lines at end of {dm_file}. "
+            r"Check and truncate the file to remove empty rows."
+        )
+    else:
+        return
+
+
 def datamap_reader(dm_file: Union[Path, str]) -> List[DatamapLine]:
     "Given a datamap csv file, returns a list of DatamapLine objects."
+    # Bail if it looks like there are lots of empty rows at the end
     try:
         headers = datamap_check(dm_file)
     except DatamapNotCSVException:
         raise
+    try:
+        tail_rows_check(dm_file)
+    except MalFormedCSVEmptyTailRowsException:
+        raise
     data = []
     logger.info(f"Reading datamap {dm_file}")
     logger.info("Checking that datamap is valid.")
@@ -508,9 +538,7 @@ def template_reader(template_file) -> Dict[str, Dict[str, Dict[Any, Any]]]:
     return shell_dict
 
 
-def extract_zip_file_to_tmpdir(
-    zfile,
-) -> Tuple[str, List[pathlib.Path]]:
+def extract_zip_file_to_tmpdir(zfile,) -> Tuple[str, List[pathlib.Path]]:
     """
     Extracts files inside zfile to a temporary dirctory, and yields
     a generator of the files as Path objects.
@@ -519,13 +547,26 @@ def extract_zip_file_to_tmpdir(
     tmp_dir = tempfile.mkdtemp()
     with zipfile.ZipFile(zfile, "r") as zf:
         zf.extractall(tmp_dir)
+        # We have to walk the temp dir to check for presence of directories.
+        # If there are any, we do not want to descend into directories seeking
+        # spreadsheet files and the descent could be massive. Raise error instead
+        # and stop?
+        # Test whether we have directories in the zip
+        fobjs = os.scandir(tmp_dir)
+        for fo in list(fobjs):
+            if os.path.isdir(fo):
+                raise NestedZipError(
+                    f"{zfile} contains nested directory called {fo.name}. Zip must be flat containing only target files. For UNIX systems, use -j flag with zip."
+                )
         target_files = [
-            x for x in os.listdir(tmp_dir) if re.match(r"(^.+\.xlsx|^.+\.xlsm)", x)
+            x
+            for x in os.listdir(tmp_dir)
+            if re.match(r"(^.+\.xlsx|^.+\.xlsm|^.+\.XLSM|^.+\.XLSX)", x)
         ]
         if target_files:
             for p in os.listdir(tmp_dir):
                 out = pathlib.Path(tmp_dir) / p
-                if out.suffix in [".xlsx", ".xlsm"]:
+                if out.suffix in [".xlsx", ".xlsm", ".XLSX", ".XLSM"]:
                     output.append(pathlib.Path(tmp_dir) / p)
             return tmp_dir, output
         else:
