@@ -5,7 +5,6 @@ from pathlib import Path
 from typing import Generator, List
 
 import pytest
-
 from engine.config import Config
 from engine.domain.datamap import DatamapLine, DatamapLineValueType
 from engine.domain.template import TemplateCell
@@ -109,6 +108,12 @@ def datamapline_list_objects() -> List[DatamapLine]:
     return [dml1, dml2, dml3, dml4]
 
 
+@pytest.fixture
+def templates_zipped_containing_dir() -> Path:
+    here = os.path.abspath(os.curdir)
+    yield Path(os.path.join(here, "tests/resources/templates_containing_dir.zip"))
+
+
 @pytest.fixture
 def templates_zipped() -> Path:
     here = os.path.abspath(os.curdir)
@@ -320,6 +325,12 @@ def datamap_single_header():
     return os.path.join(here, "tests/resources/datamap_single_header.csv")
 
 
+@pytest.fixture
+def datamap_empty_tail_rows():
+    here = os.path.abspath(os.curdir)
+    return os.path.join(here, "tests/resources/datamap_empty_tail_rows.csv")
+
+
 @pytest.fixture
 def datamap_no_type_col():
     here = os.path.abspath(os.curdir)
